import React from "react";
import { Button } from "@components/Button";

export interface GridCardProps {
  title: string;
  subtitle?: string;
  buttonCaption?: string;
  buttonTarget?: string;
  img?: string;
  imgAlt?: string;
  children?: React.ReactNode;
  light?: boolean;
  icon?: React.ReactNode;
  className?: string;
}

export const GridCard: React.FC<GridCardProps> = ({
  title,
  subtitle,
  children,
  buttonCaption,
  buttonTarget,
  img,
  imgAlt,
  light = false,
  icon,
  className,
}: GridCardProps) => (
  <div
    className={`${
      light ? "bg-pearl-500 text-grey-900" : "bg-grey-900 text-white"
    }   flex-1 flex flex-col justify-between ${className || ""}`}
  >
    <div className="flex flex-col">
      {Boolean(img) && (
        <img className="object-cover aspect-[16/8]" src={img} alt={imgAlt} />
      )}
      <div
        className={`${
          light ? "text-grey-900" : "text-white"
        } prose prose-headings:font-karla p-8`}
      >
        {Boolean(subtitle) && (
          <h4 className={`${light ? "text-grey-900" : "text-white"} uppercase`}>
            {subtitle}
          </h4>
        )}
        <h2
          className={`${light ? "text-grey-900" : "text-white"} ${
            subtitle ? "" : "mt-8"
          }`}
        >
          {title}
        </h2>
        <p className="leading-6">{children}</p>
      </div>
    </div>
    {buttonCaption && (
      <div className="px-8 pb-8 flex justify-end">
        <Button
          className="!px-8 !py-2 md:!py-3 md:!px-8"
          text={buttonCaption}
          href={buttonTarget}
          type={light ? "primary" : "tertiary"}
          icon={icon}
        />
      </div>
    )}
  </div>
);
