import React, { CSSProperties } from "react";
import { Pill } from "@components/Pill";
import { Time, Location } from "@carbon/icons-react";
import { INewsCard } from "@interfaces/INews";
import { Link } from "@components/Link";
type PillColor = "dark" | "white";

export const HorizontalNewsCard: React.FC<INewsCard> = ({
  image,
  title,
  description,
  time,
  location,
  category,
  href,
  type = "dark",
  className = "",
  customBackgroundColor,
  textColor = "",
}) => {
  const inlineStyle: CSSProperties = {
    backgroundColor: customBackgroundColor,
  };
  const PILL_COLOR_MAPPING: Record<string, PillColor> = {
    dark: "white",
    light: "dark",
  };
  const STYLE_MAPPING: Record<string, Record<string, string>> = {
    dark: {
      outerContainer: "flex bg-grey-900",
      contentContainer:
        "group order-1 w-full flex flex-col justify-between md:w-3/5 xl:w-2/3 p-7",
      linkContainer: "mb-5 sm:mb-0",
    },
    light: {
      outerContainer: "flex bg-pearl-500",
      contentContainer:
        "group order-1 w-full flex flex-col justify-between md:w-3/5 xl:w-2/3 p-7",
      linkContainer: "mb-5 sm:mb-0",
    },
    custom: {
      outerContainer: "flex",
      contentContainer:
        "group order-1 w-full flex flex-col justify-between md:w-3/5 xl:w-2/3 p-7",
      linkContainer: "mb-5 sm:mb-0",
    },
  };
  const TEXT_STYLE_MAPPING: Record<string, Record<string, string>> = {
    dark: {
      heading:
        "group-peer-hover:multi-line-underline group-hover:multi-line-underline xl:multi-line-3-white font-karla text-2xl md:text-3xl leading-8 md:leading-9 font-bold text-white tracking-tight line-clamp-2 sm:line-clamp-3 xl:line-clamp-none",
      paragraph:
        "mt-2 md:mt-3 font-plex text-base md:text-lg leading-6 md:leading-7 font-normal text-grey-100 line-clamp-3 lg:line-clamp-4 xl:line-clamp-3",
      event:
        "mt-2 md:mt-3 font-plex text-base md:text-lg leading-6 md:leading-7 font-normal text-grey-50",
    },
    light: {
      heading:
        "group-peer-hover:multi-line-underline group-hover:multi-line-underline xl:multi-line-3-grey-900 font-karla text-2xl md:text-3xl leading-8 md:leading-9 font-bold text-grey-900 tracking-tight line-clamp-2 sm:line-clamp-3 xl:line-clamp-none",
      paragraph:
        "mt-2 md:mt-3 font-plex text-base md:text-lg leading-6 md:leading-7 font-normal text-grey-900 line-clamp-3 lg:line-clamp-4 xl:line-clamp-3",
      event:
        "mt-2 md:mt-3 font-plex text-base md:text-lg leading-6 md:leading-7 font-normal text-grey-900",
    },
  };
  const renderCardContent = (type: "light" | "dark") => {
    if (type === "light") {
      return (
        <p
          className={
            customBackgroundColor
              ? TEXT_STYLE_MAPPING[textColor]["paragraph"]
              : TEXT_STYLE_MAPPING[type]["paragraph"]
          }
        >
          {description}
        </p>
      );
    }
    if (type === "dark") {
      return (
        <div
          className={
            customBackgroundColor
              ? TEXT_STYLE_MAPPING[textColor]["event"]
              : TEXT_STYLE_MAPPING[type]["event"]
          }
        >
          {time && (
            <span className="flex items-center">
              <Time size={16} className="mr-1 md:mr-2" />
              {time}
            </span>
          )}
          {location && (
            <span className="flex items-center mt-1">
              <Location size={16} className="mr-1 md:mr-2" />
              {location}
            </span>
          )}
        </div>
      );
    }
    return null;
  };
  return (
    <div
      style={inlineStyle}
      className={`${
        customBackgroundColor
          ? STYLE_MAPPING["custom"]["outerContainer"]
          : STYLE_MAPPING[type]["outerContainer"]
      } ${className}`}
    >
      <div className="peer order-2 hidden md:block md:w-2/5 xl:w-1/3">
        <Link to={href} className="block h-full aspect-square">
          <img
            className="w-full h-full object-cover"
            alt={image.alt}
            src={image.src}
          />
        </Link>
      </div>
      <div
        className={
          customBackgroundColor
            ? STYLE_MAPPING["custom"]["contentContainer"]
            : STYLE_MAPPING[type]["contentContainer"]
        }
      >
        <Link
          to={href}
          className={
            customBackgroundColor
              ? STYLE_MAPPING["custom"]["linkContainer"]
              : STYLE_MAPPING[type]["linkContainer"]
          }
        >
          <h5
            className={
              customBackgroundColor
                ? TEXT_STYLE_MAPPING[textColor]["heading"]
                : TEXT_STYLE_MAPPING[type]["heading"]
            }
          >
            {title}
          </h5>
          {renderCardContent(type)}
        </Link>
        <div className="hidden md:flex flex-wrap">
          <Pill
            type={PILL_COLOR_MAPPING[type]}
            size="sm"
            rounded
            href={category.href}
            title={category.title}
          />
        </div>
      </div>
    </div>
  );
};
