import React from "react";
import { Pill } from "@components/Pill";
import { Link } from "@components/Link";
import { INewsImage, INewsCategory } from "@interfaces/INews";
type PillColor = "dark" | "white";

export interface MiniCardProps {
  name?: string;
  subtitle?: React.ReactNode;
  image: INewsImage;
  rightImage?: INewsImage;
  rightImageHref?: string;
  tags?: INewsCategory[];
  href?: string;
  type?: "light" | "dark";
  className?: string;
}

export const MiniCard: React.FC<MiniCardProps> = ({
  name,
  image,
  subtitle,
  tags,
  href,
  type = "light",
  className = "",
  rightImage,
  rightImageHref,
}) => {
  const PILL_COLOR_MAPPING: Record<string, PillColor> = {
    dark: "white",
    light: "dark",
  };
  const imageEl = (
    <img
      className="w-full h-full object-cover"
      alt={image.alt}
      src={image.src}
    />
  );
  const rightImageEl = rightImage && (
    <img
      className="w-full object-contain min-w-8"
      src={rightImage.src}
      alt={rightImage.alt}
    />
  );
  const titleEl = (
    <h1 className="font-karla text-base md:text-3xl md:leading-8 font-bold text-grey-900 md:mb-2 line-clamp-2">
      {name}
    </h1>
  );
  return (
    <div
      className={`flex bg-grey-100 w-full md:max-w-screen-md h-[75px] md:h-[180px] ${className}`}
    >
      <div className="h-full aspect-square">
        {href ? (
          <Link to={href} className="block h-full aspect-square">
            {imageEl}
          </Link>
        ) : (
          imageEl
        )}
      </div>
      <div className="relative flex gap-4 px-2 py-1 md:px-8 md:py-4 w-full h-full justify-between overflow-hidden">
        <div className="flex flex-col justify-between">
          <div>
            {href ? <Link to={href}>{titleEl}</Link> : titleEl}
            {subtitle && (
              <span className="text-sm flex flex-wrap font-plex font-normal text-grey-500 gap-1 md:gap-2">
                {subtitle}
              </span>
            )}
          </div>
          {tags && (
            <div className="hidden md:flex flex-wrap gap-2">
              {tags.map((tag) => (
                <Pill
                  key={tag.title}
                  type={PILL_COLOR_MAPPING[type]}
                  size="sm"
                  rounded
                  href={tag.href}
                  title={tag.title}
                />
              ))}
            </div>
          )}
        </div>
        {rightImage && (
          <div className="aspect-square flex items-start justify-end">
            {rightImageHref ? (
              <Link to={rightImageHref} className="block h-full aspect-square">
                {rightImageEl}
              </Link>
            ) : (
              rightImageEl
            )}
          </div>
        )}
      </div>
    </div>
  );
};
