import React from "react";

export interface ProseProps {
  notProse?: boolean;
  children: React.ReactNode;
  className?: string;
}

export const Prose: React.FC<ProseProps> = ({ children, notProse, className }) => {
  const TEXT_STYLE_MAPPING: Record<string, string> = {
    main: `font-plex text-grey-900 ${notProse ? "" : "prose"}`,
    headings: "prose-headings:font-karla",
    subheading: "prose-h2:text-3xl",
    bullets: "prose-li:marker:text-grey-900",
    blockquote:
      "prose-blockquote:border-l-2 sm:prose-blockquote:border-l-4 prose-blockquote:border-grey-900 prose-blockquote:text-sm sm:prose-blockquote:text-base prose-blockquote:not-italic prose-blockquote:leading-5 sm:prose-blockquote:leading-6 prose-blockquote:font-semibold prose-blockquote:tracking-wider prose-blockquote:uppercase",
    code: "prose-code:before:content-none prose-code:after:content-none",
    image: "prose-img:w-full prose-img:h-auto prose-img:rounded-sm",
    video: "prose-video:w-full prose-video:h-auto",
  };

  return (
    <article
      className={`max-w-full ${TEXT_STYLE_MAPPING["main"]} ${
        TEXT_STYLE_MAPPING["headings"]
      } ${TEXT_STYLE_MAPPING["subheading"]} ${TEXT_STYLE_MAPPING["bullets"]} ${
        TEXT_STYLE_MAPPING["blockquote"]
      } ${TEXT_STYLE_MAPPING["image"]} ${TEXT_STYLE_MAPPING["video"]} ${
        TEXT_STYLE_MAPPING["code"]
      } ${className || ""}`}
    >
      {children}
    </article>
  );
};
