import * as React from "react";
import type { Story } from "@ladle/react";
import { Button } from "@components/Button";
import { Email } from "@carbon/icons-react";

interface ButtonConfigProps {
  text: string;
  type: "primary" | "secondary" | "tertiary";
  disabled: boolean;
  size: "xs" | "sm" | "md" | "lg" | "xl";
}

export const ButtonStory: Story<ButtonConfigProps> = ({
  type,
  disabled,
  size,
  text,
}: ButtonConfigProps) => (
  <div className="grid grid-cols-3 gap-5">
    {/* Default */}
    <div>
      <Button text={text} type={type} size={size} disabled={disabled} />
    </div>
    {/* Default with Icon */}
    <div>
      <Button
        text={text}
        type={type}
        size={size}
        disabled={disabled}
        icon={<Email />}
      />
    </div>
    {/* Default with Icon right */}
    <div>
      <Button
        text={text}
        type={type}
        size={size}
        disabled={disabled}
        icon={<Email />}
        iconRight
      />
    </div>
    {/* Rounded */}
    <div>
      <Button text={text} type={type} size={size} disabled={disabled} rounded />
    </div>
    {/* Rounded with Icon */}
    <div>
      <Button
        text={text}
        type={type}
        size={size}
        disabled={disabled}
        rounded
        icon={<Email />}
      />
    </div>
    {/* Rounded with Icon right */}
    <div>
      <Button
        text={text}
        type={type}
        size={size}
        disabled={disabled}
        rounded
        icon={<Email />}
        iconRight
      />
    </div>
    {/* Circular */}
    <div>
      <Button
        type={type}
        size={size}
        disabled={disabled}
        circular
        icon={<Email />}
      />
    </div>
  </div>
);

ButtonStory.args = {
  text: "Button",
  disabled: false,
};
ButtonStory.argTypes = {
  type: {
    options: ["primary", "secondary", "tertiary"],
    control: { type: "radio" },
    defaultValue: "primary",
  },
  size: {
    options: ["xs", "sm", "md", "lg", "xl"],
    control: { type: "radio" },
    defaultValue: "md",
  },
};
export default {
  title: "Atoms",
};
ButtonStory.storyName = "Button";
