import * as React from "react";
import { Toolbar } from "@components/Toolbar";
import {
  ChoroplethMap,
  Folders,
  Chat,
  Calendar,
  ApplicationVirtual,
  Email,
  Search,
  UserAvatar,
  Notification,
} from "@carbon/icons-react";
import { IToolbarItem } from "@interfaces/IHeader";

const iconClasses = "w-6 h-6 sm:mr-2 mb-1 sm:mb-0 flex-shrink-0";
const TOOLBAR_ITEMS: IToolbarItem[] = [
  {
    title: "Map",
    icon: <ChoroplethMap className={iconClasses} />,
    target: `/de/network/map`,
  },
  {
    title: "Knowledge Hub",
    icon: <Folders className={iconClasses} />,
    target: `/de/hub`,
    onlyDesktop: true,
  },
  {
    title: "Community",
    icon: <Chat className={iconClasses} />,
    target: `/de/network/community`,
  },
  {
    title: "Events",
    icon: <Calendar className={iconClasses} />,
    target: `/de/events`,
  },
  {
    title: "Fab City OS",
    icon: <ApplicationVirtual className={iconClasses} />,
    target: `/de/projects/fcos`,
  },
];

const EXTENDED_TOOLBAR_ITEMS: IToolbarItem[] = [
  {
    title: "Search",
    icon: <Search size={24} />,
    target: "/search",
  },
  {
    title: "Email",
    icon: <Email size={24} />,
    target: "/email",
  },
  {
    title: "Notification",
    icon: <Notification size={24} />,
    target: "/notification",
  },
  {
    title: "User",
    icon: <UserAvatar size={24} />,
    target: "/user",
  },
];

export const ToolbarStory = () => (
  <div>
    <div>
      <Toolbar isMobileOpen={false} items={TOOLBAR_ITEMS} />
    </div>
    <div className="mt-10">
      <Toolbar
        isMobileOpen={false}
        items={TOOLBAR_ITEMS}
        extendedToolbarItems={EXTENDED_TOOLBAR_ITEMS}
      />
    </div>
  </div>
);

export default {
  title: "Molecules",
};
ToolbarStory.storyName = "Toolbar";
